LIBNAME YourLibname 'Your Directory';

DATA data;
  SET YourLibname.data;
RUN;

/*
Description dataset
id:  id of the subject
affect:  dependent variable
day:  7 days
signal: 7 signals
measurements:  2 measurements
diagnosis:  2 groups of 17 subjects
weekday:  see format below
time:  time passed since the start of the day (7:30 a.m.)
passeddays:  number of days passed since the start of the study
*/;

PROC FORMAT;
  VALUE WeekDayFormat
  1 = 'Sunday'
  2 = 'Monday'
  3 = 'Thuesday'
  4 = 'Wednesday'
  5 = 'Thursday'
  6 = 'Friday'
  7 = 'Saturday';
RUN;

/**************************************************************************************************/
/**************************************************************************************************/
/****MODEL (1) and MODELS WITH GROUP-SPECIFIC VARIANCES OR SERIAL AUTOCORRELATION******************/
/**************************************************************************************************/
/**************************************************************************************************/

DATA data;
  SET data;
    phd=time*(measurement=1)+(time+0.1)*(measurement=2);
RUN;

TITLE "Model (1)";
PROC MIXED DATA=data;
CLASS id day signal measurement diagnosis weekday;
MODEL valence = diagnosis weekday /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN;
RANDOM intercept /SUBJECT=day(id) TYPE=UN;
RANDOM intercept / SUBJECT=signal(day*id) TYPE=UN;
REPEATED measurement / SUBJECT=day(id) TYPE=SP(EXP)(time) LOCAL;
FORMAT weekday weekdayformat.;
RUN;

TITLE "Between Subject Variance Group-Specific";
PROC MIXED DATA=data;
CLASS id day signal phd diagnosis weekday;
MODEL valence = diagnosis weekday /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN GROUP=diagnosis;
RANDOM intercept /SUBJECT=day(id) TYPE=UN;
RANDOM intercept / SUBJECT=signal(day*id) TYPE=UN;
REPEATED phd / SUBJECT=day(id) TYPE=SP(EXP)(time) LOCAL;
FORMAT weekday weekdayformat.;
RUN;

TITLE "Long-Term Between Day Variance Group-Specific";
PROC MIXED DATA=data;
CLASS id day signal phd diagnosis weekday;
MODEL valence = diagnosis weekday /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN;
RANDOM intercept /SUBJECT=day(id) TYPE=UN GROUP=diagnosis;
RANDOM intercept / SUBJECT=signal(day*id) TYPE=UN;
REPEATED phd / SUBJECT=day(id) TYPE=SP(EXP)(time) LOCAL;
FORMAT weekday weekdayformat.;
RUN;

TITLE "Short-Term Within Day Variance Group-Specific";
PROC MIXED DATA=data;
CLASS id day signal phd diagnosis weekday;
MODEL valence = diagnosis weekday /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN;
RANDOM intercept /SUBJECT=day(id) TYPE=UN;
RANDOM intercept / SUBJECT=signal(day*id) TYPE=UN GROUP=diagnosis;
REPEATED phd / SUBJECT=day(id) TYPE=SP(EXP)(time) LOCAL;
FORMAT weekday weekdayformat.;
RUN;

TITLE "Within Day Serial Autocorrelation Group-Specific";
PROC MIXED DATA=data;
CLASS id day signal phd diagnosis weekday;
MODEL valence = diagnosis weekday /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN;
RANDOM intercept /SUBJECT=day(id) TYPE=UN;
RANDOM intercept / SUBJECT=signal(day*id) TYPE=UN;
REPEATED phd / SUBJECT=day(id) TYPE=SP(EXP)(time) LOCAL GROUP=diagnosis;
FORMAT weekday weekdayformat.;
RUN;

/**************************************************************************************************/
/**************************************************************************************************/
/****SCENARIOS WITH OTHER DATASETS*****************************************************************/
/**************************************************************************************************/
/**************************************************************************************************/

/*Multiple signals nested within days within subjects (1 measurement)*/
DATA subset1;
  SET data;
    IF NOT (measurement=1) THEN DELETE;
RUN;

TITLE "Multiple signals nested within days within subjects (1 measurement)";
PROC MIXED DATA=subset1;
CLASS id day  signal phd diagnosis weekday;
MODEL valence = diagnosis weekday  /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN;
RANDOM intercept /SUBJECT=day(id) TYPE=UN;
REPEATED phd / SUBJECT=day(id) TYPE=SP(EXP)(time) LOCAL; 
FORMAT weekday weekdayformat.;
RUN;

/*Multiple measurements nested within days within subjects (1 signal)*/
DATA subset2;
  SET data;
    IF NOT (signal=2) THEN DELETE;
	passeddays=day;
	dayorder=day*(measurement=1)+(day+0.1)*(measurement=2);
RUN;

TITLE "Multiple measurements nested within days within subjects (1 signal)";
PROC MIXED DATA=subset2;
CLASS id day signal dayorder diagnosis weekday;
MODEL valence = diagnosis weekday  /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN;
RANDOM intercept /SUBJECT=day(id) TYPE=UN;
REPEATED dayorder / SUBJECT=id TYPE=SP(EXP)(passeddays) LOCAL; 
FORMAT weekday weekdayformat.;
RUN;

/*Multiple days nested within subjects (1 measurement and 1 signal)*/
DATA subset3;
  SET data;
    IF NOT (measurement=2) THEN DELETE;
	IF NOT (signal=3) THEN DELETE;
	passeddays=day;
	dayorder=day;
RUN;

TITLE "Multiple days nested within subjects (1 measurement and 1 signal)";
PROC MIXED DATA=subset3;
CLASS id day signal dayorder diagnosis weekday;
MODEL valence = diagnosis weekday  /SOLUTION;
RANDOM intercept /SUBJECT=id TYPE=UN;
REPEATED dayorder / SUBJECT=id TYPE=SP(EXP)(passeddays) LOCAL; 
FORMAT weekday weekdayformat.;
RUN;
